[SCM] Debian Qt/KDE packaging tools branch, master, updated. debian/0.15.15-1-g28d4814

Jonathan Riddell jriddell-guest at moszumanska.debian.org
Fri Sep 26 12:59:15 UTC 2014


Gitweb-URL: http://git.debian.org/?p=pkg-kde/pkg-kde-tools.git;a=commitdiff;h=28d4814

The following commit has been merged in the master branch:
commit 28d48144ae72af0cac62b3fc7c96f77033abe5a3
Author: Jonathan Riddell <jr at jriddell.org>
Date:   Fri Sep 26 14:59:08 2014 +0200

     Add packaging for Frameworks 5 packages:
    
    * Add packaging for Frameworks 5 packages:
     - datalib/kf5_flags
     - Debhelper buildsystem and sequence flags
     - qt-kde-team/3 include scripts
---
 datalib/kf5_flags                                  |  4 ++
 debian/changelog                                   | 10 ++++
 perllib/Debian/Debhelper/Buildsystem/kf5.pm        | 57 ++++++++++++++++++++++
 .../Debian/Debhelper/Sequence/{kde.pm => kf5.pm}   | 22 ++++-----
 qt-kde-team/{2 => 3}/README                        |  0
 qt-kde-team/{2 => 3}/commands                      |  0
 qt-kde-team/{2 => 3}/debian-qt-kde.mk              |  8 +--
 qt-kde-team/{2 => 3}/dhmk.mk                       |  0
 qt-kde-team/{2 => 3}/dhmk.pl                       |  0
 qt-kde-team/{2 => 3}/library-packages.mk           |  0
 qt-kde-team/{2 => 3}/list-missing.mk               |  0
 qt-kde-team/{2 => 3}/policy.mk                     |  0
 qt-kde-team/{2 => 3}/policy/unstable.mk            |  0
 13 files changed, 84 insertions(+), 17 deletions(-)

diff --git a/datalib/kf5_flags b/datalib/kf5_flags
new file mode 100644
index 0000000..a9aa075
--- /dev/null
+++ b/datalib/kf5_flags
@@ -0,0 +1,4 @@
+-DCMAKE_BUILD_TYPE=Debian
+-DCMAKE_USE_RELATIVE_PATHS=ON
+-DCMAKE_INSTALL_SYSCONFDIR=/etc
+-DKDE_INSTALL_USE_QT_SYS_PATHS=ON
diff --git a/debian/changelog b/debian/changelog
index 199f689..997801f 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,13 @@
+pkg-kde-tools (0.15.16) UNRELEASED; urgency=medium
+
+  [ Rohan Garg ]
+  * Add packaging for Frameworks 5 packages:
+   - datalib/kf5_flags
+   - Debhelper buildsystem and sequence flags
+   - qt-kde-team/3 include scripts
+
+ -- Jonathan Riddell <jriddell at ubuntu.com>  Fri, 26 Sep 2014 14:50:15 +0200
+
 pkg-kde-tools (0.15.15) unstable; urgency=medium
 
   * The fix for #744173 required to convert non-anchored regexps to anchored
diff --git a/perllib/Debian/Debhelper/Buildsystem/kf5.pm b/perllib/Debian/Debhelper/Buildsystem/kf5.pm
new file mode 100644
index 0000000..c472024
--- /dev/null
+++ b/perllib/Debian/Debhelper/Buildsystem/kf5.pm
@@ -0,0 +1,57 @@
+# A debhelper build system class for building KDE Frameworks 5 packages.
+# It is based on cmake class but passes Frameworks 5 flags by default.
+#
+# Copyright: © 2009 Modestas Vainius
+# License: GPL-2+
+
+package Debian::Debhelper::Buildsystem::kf5;
+
+use strict;
+use warnings;
+use Debian::Debhelper::Dh_Lib qw(error);
+use Dpkg::Version qw();
+
+use base 'Debian::Debhelper::Buildsystem::cmake';
+
+sub DESCRIPTION {
+    "CMake with KDE Frameworks 5 flags"
+}
+
+sub KF5_FLAGS_FILE {
+    my $file = "kf5_flags";
+    if (! -r $file) {
+        $file = "/usr/share/pkg-kde-tools/lib/kf5_flags";
+    }
+    if (! -r $file) {
+        error "kf5_flags file could not be found";
+    }
+    return $file;
+}
+
+# Use shell for parsing contents of the kf5_flags file
+sub get_kf5_flags {
+    my $this=shift;
+    my $file = KF5_FLAGS_FILE;
+    my ($escaped_flags, @escaped_flags);
+    my $flags;
+
+    # Read escaped flags from the file
+    open(KF5_FLAGS, "<", $file) || error("unable to open KDE Frameworks 5 flags file: $file");
+    @escaped_flags = <KF5_FLAGS>;
+    chop @escaped_flags;
+    $escaped_flags = join(" ", @escaped_flags);
+    close KF5_FLAGS;
+
+    # Unescape flags using shell
+    $flags = `$^X -w -Mstrict -e 'print join("\x1e", \@ARGV);' -- $escaped_flags`;
+    return split("\x1e", $flags);
+}
+
+sub configure {
+    my $this=shift;
+    my @flags = $this->get_kf5_flags();
+
+    return $this->SUPER::configure(@flags, @_);
+}
+
+1;
diff --git a/qt-kde-team/2/README b/qt-kde-team/3/README
similarity index 100%
copy from qt-kde-team/2/README
copy to qt-kde-team/3/README
diff --git a/qt-kde-team/2/commands b/qt-kde-team/3/commands
similarity index 100%
copy from qt-kde-team/2/commands
copy to qt-kde-team/3/commands
diff --git a/qt-kde-team/2/debian-qt-kde.mk b/qt-kde-team/3/debian-qt-kde.mk
similarity index 92%
copy from qt-kde-team/2/debian-qt-kde.mk
copy to qt-kde-team/3/debian-qt-kde.mk
index d976b62..09c290a 100644
--- a/qt-kde-team/2/debian-qt-kde.mk
+++ b/qt-kde-team/3/debian-qt-kde.mk
@@ -14,7 +14,7 @@ dqk_upstream_version ?= $(shell dpkg-parsechangelog | sed -n '/^Version:/{ s/^Ve
 dqk_destdir = $(CURDIR)/debian/tmp
 
 # We want to use kde and pkgkde-symbolshelper plugins by default
-dh := --with=kde,pkgkde-symbolshelper $(dh)
+dh := --with=kf5,pkgkde-symbolshelper $(dh)
 
 # dqk_disable_policy_check lists distributions for which policy check should be
 # disabled
@@ -52,10 +52,6 @@ ifneq (,$(findstring yes, $(dqk_link_with_no_undefined)))
     endif
 endif
 
-# Since cmake 2.6.2 or higher is required from now on, enable relative paths to
-# get more ccache hits.
-$(call set_command_options,dh_auto_configure, += "-u-DCMAKE_USE_RELATIVE_PATHS=ON")
-
 # Run dh_sameversiondep
 run_dh_sameversiondep:
 	dh_sameversiondep
@@ -89,7 +85,7 @@ install_to_doc-html_package:
 	        echo Building $$pkg HTML docs...; \
 	        mkdir -p $(dqk_doc-html_dir)/usr/share/doc/kde/HTML/en/$$pkg; \
 	        cd $(dqk_doc-html_dir)/usr/share/doc/kde/HTML/en/$$pkg; \
-	        meinproc4 $(dqk_destdir)/usr/share/doc/kde/HTML/en/$$pkg/index.docbook; \
+	        meinproc5 $(dqk_destdir)/usr/share/doc/kde/HTML/en/$$pkg/index.docbook; \
 	    done; \
 	    for pkg in $(DOC_HTML_PRUNE) ; do \
 	        rm -rf $(dqk_doc-html_dir)/usr/share/doc/kde/HTML/en/$$pkg; \
diff --git a/perllib/Debian/Debhelper/Sequence/kde.pm b/perllib/Debian/Debhelper/Sequence/kf5.pm
similarity index 53%
copy from perllib/Debian/Debhelper/Sequence/kde.pm
copy to perllib/Debian/Debhelper/Sequence/kf5.pm
index ca25d78..566d977 100644
--- a/perllib/Debian/Debhelper/Sequence/kde.pm
+++ b/perllib/Debian/Debhelper/Sequence/kf5.pm
@@ -1,5 +1,5 @@
 {
-    package Debian::Debhelper::Sequence::kde;
+    package Debian::Debhelper::Sequence::kf5;
     use Debian::Debhelper::Dh_Version;
     use Debian::Debhelper::Dh_Lib qw(error);
 
@@ -19,23 +19,23 @@
         return 0;
     }
     unless (ensure_debhelper_version(7, 3, 16)) {
-        error "debhelper addon 'kde' requires debhelper 7.3.16 or later";
+        error "debhelper addon 'kf5' requires debhelper 7.3.16 or later";
     }
 
     1;
 }
 
-# Build with kde buildsystem by default
-add_command_options("dh_auto_configure", "--buildsystem=kde");
-add_command_options("dh_auto_build", "--buildsystem=kde");
-add_command_options("dh_auto_test", "--buildsystem=kde");
-add_command_options("dh_auto_install", "--buildsystem=kde");
-add_command_options("dh_auto_clean", "--buildsystem=kde");
+# Build with kf5 buildsystem by default
+add_command_options("dh_auto_configure", "--buildsystem=kf5");
+add_command_options("dh_auto_build", "--buildsystem=kf5");
+add_command_options("dh_auto_test", "--buildsystem=kf5");
+add_command_options("dh_auto_install", "--buildsystem=kf5");
+add_command_options("dh_auto_clean", "--buildsystem=kf5");
 
-# Omit usr/lib/kde4 from dh_makeshlibs by default
-add_command_options("dh_makeshlibs", "-Xusr/lib/kde4/");
+# Omit libkdeinit5_* from dh_makeshlibs by default
+add_command_options("dh_makeshlibs", "-Xusr/lib/libkdeinit5_*");
 
 # Exclude kde documentation from dh_compress by default
 add_command_options("dh_compress",
     qw(-X.dcl -X.docbook -X-license -X.tag -X.sty -X.el));
 
@@ -19,23 +19,23 @@
 
-# Exclude kde documentation from dh_compress by default
+# Exclude kf5 documentation from dh_compress by default
 add_command_options("dh_compress",
     qw(-X.dcl -X.docbook -X-license -X.tag -X.sty -X.el));
diff --git a/qt-kde-team/2/dhmk.mk b/qt-kde-team/3/dhmk.mk
similarity index 100%
copy from qt-kde-team/2/dhmk.mk
copy to qt-kde-team/3/dhmk.mk
diff --git a/qt-kde-team/2/dhmk.pl b/qt-kde-team/3/dhmk.pl
similarity index 100%
copy from qt-kde-team/2/dhmk.pl
copy to qt-kde-team/3/dhmk.pl
diff --git a/qt-kde-team/2/library-packages.mk b/qt-kde-team/3/library-packages.mk
similarity index 100%
copy from qt-kde-team/2/library-packages.mk
copy to qt-kde-team/3/library-packages.mk
diff --git a/qt-kde-team/2/list-missing.mk b/qt-kde-team/3/list-missing.mk
similarity index 100%
copy from qt-kde-team/2/list-missing.mk
copy to qt-kde-team/3/list-missing.mk
diff --git a/qt-kde-team/2/policy.mk b/qt-kde-team/3/policy.mk
similarity index 100%
copy from qt-kde-team/2/policy.mk
copy to qt-kde-team/3/policy.mk
diff --git a/qt-kde-team/2/policy/unstable.mk b/qt-kde-team/3/policy/unstable.mk
similarity index 100%
copy from qt-kde-team/2/policy/unstable.mk
copy to qt-kde-team/3/policy/unstable.mk

-- 
Debian Qt/KDE packaging tools



More information about the pkg-kde-commits mailing list